@@ -8,6 +8,7 @@ import akro
 import numpy as np
 import tensorflow as tf
 
+from garage.experiment import deterministic
 from garage.tf.models import CategoricalMLPModel
 from garage.tf.policies.policy import StochasticPolicy
 
@@ -53,10 +54,12 @@ class CategoricalMLPPolicy(StochasticPolicy):
                  name='CategoricalMLPPolicy',
                  hidden_sizes=(32, 32),
                  hidden_nonlinearity=tf.nn.tanh,
-                 hidden_w_init=tf.initializers.glorot_uniform(),
+                 hidden_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  hidden_b_init=tf.zeros_initializer(),
                  output_nonlinearity=None,
-                 output_w_init=tf.initializers.glorot_uniform(),
+                 output_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  output_b_init=tf.zeros_initializer(),
                  layer_normalization=False):
         if not isinstance(env_spec.action_space, akro.Discrete):
@@ -101,7 +104,12 @@ class CategoricalMLPPolicy(StochasticPolicy):
                                                           self._obs_dim))
             self._dist = self.model.build(state_input).dist
             self._f_prob = tf.compat.v1.get_default_session().make_callable(
-                [tf.argmax(self._dist.sample(), -1), self._dist.probs],
+                [
+                    tf.argmax(
+                        self._dist.sample(
+                            seed=deterministic.get_tf_seed_stream()), -1),
+                    self._dist.probs
+                ],
                 feed_list=[state_input])
 
     def build(self, state_input, name=None):
@@ -190,8 +198,7 @@ class CategoricalMLPPolicy(StochasticPolicy):
     def clone(self, name):
         """Return a clone of the policy.
 
-        It only copies the configuration of the primitive,
-        not the parameters.
+        It copies the configuration of the primitive and also the parameters.
 
         Args:
             name (str): Name of the newly created policy. It has to be
@@ -202,16 +209,19 @@ class CategoricalMLPPolicy(StochasticPolicy):
             garage.tf.policies.Policy: Newly cloned policy.
 
         """
-        return self.__class__(name=name,
-                              env_spec=self._env_spec,
-                              hidden_sizes=self._hidden_sizes,
-                              hidden_nonlinearity=self._hidden_nonlinearity,
-                              hidden_w_init=self._hidden_w_init,
-                              hidden_b_init=self._hidden_b_init,
-                              output_nonlinearity=self._output_nonlinearity,
-                              output_w_init=self._output_w_init,
-                              output_b_init=self._output_b_init,
-                              layer_normalization=self._layer_normalization)
+        new_policy = self.__class__(
+            name=name,
+            env_spec=self._env_spec,
+            hidden_sizes=self._hidden_sizes,
+            hidden_nonlinearity=self._hidden_nonlinearity,
+            hidden_w_init=self._hidden_w_init,
+            hidden_b_init=self._hidden_b_init,
+            output_nonlinearity=self._output_nonlinearity,
+            output_w_init=self._output_w_init,
+            output_b_init=self._output_b_init,
+            layer_normalization=self._layer_normalization)
+        new_policy.model.parameters = self.model.parameters
+        return new_policy
 
     def __getstate__(self):
         """Object.__getstate__.
