@@ -8,6 +8,7 @@ import akro
 import numpy as np
 import tensorflow as tf
 
+from garage.experiment import deterministic
 from garage.tf.models import GaussianGRUModel
 from garage.tf.policies.policy import StochasticPolicy
 
@@ -66,12 +67,15 @@ class GaussianGRUPolicy(StochasticPolicy):
                  hidden_dim=32,
                  name='GaussianGRUPolicy',
                  hidden_nonlinearity=tf.nn.tanh,
-                 hidden_w_init=tf.initializers.glorot_uniform(),
+                 hidden_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  hidden_b_init=tf.zeros_initializer(),
                  recurrent_nonlinearity=tf.nn.sigmoid,
-                 recurrent_w_init=tf.initializers.glorot_uniform(),
+                 recurrent_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  output_nonlinearity=None,
-                 output_w_init=tf.initializers.glorot_uniform(),
+                 output_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  output_b_init=tf.zeros_initializer(),
                  hidden_state_init=tf.zeros_initializer(),
                  hidden_state_init_trainable=False,
@@ -312,8 +316,7 @@ class GaussianGRUPolicy(StochasticPolicy):
     def clone(self, name):
         """Return a clone of the policy.
 
-        It only copies the configuration of the primitive,
-        not the parameters.
+        It copies the configuration of the primitive and also the parameters.
 
         Args:
             name (str): Name of the newly created policy. It has to be
@@ -324,7 +327,7 @@ class GaussianGRUPolicy(StochasticPolicy):
             garage.tf.policies.GaussianGRUPolicy: Newly cloned policy.
 
         """
-        return self.__class__(
+        new_policy = self.__class__(
             name=name,
             env_spec=self._env_spec,
             hidden_dim=self._hidden_dim,
@@ -343,6 +346,8 @@ class GaussianGRUPolicy(StochasticPolicy):
             init_std=self._init_std,
             layer_normalization=self._layer_normalization,
             state_include_action=self._state_include_action)
+        new_policy.model.parameters = self.model.parameters
+        return new_policy
 
     def __getstate__(self):
         """Object.__getstate__.
