@@ -8,6 +8,7 @@ import akro
 import numpy as np
 import tensorflow as tf
 
+from garage.experiment import deterministic
 from garage.tf.models import GaussianMLPModel
 from garage.tf.policies.policy import StochasticPolicy
 
@@ -74,10 +75,12 @@ class GaussianMLPPolicy(StochasticPolicy):
                  name='GaussianMLPPolicy',
                  hidden_sizes=(32, 32),
                  hidden_nonlinearity=tf.nn.tanh,
-                 hidden_w_init=tf.initializers.glorot_uniform(),
+                 hidden_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  hidden_b_init=tf.zeros_initializer(),
                  output_nonlinearity=None,
-                 output_w_init=tf.initializers.glorot_uniform(),
+                 output_w_init=tf.initializers.glorot_uniform(
+                     seed=deterministic.get_tf_seed_stream()),
                  output_b_init=tf.zeros_initializer(),
                  learn_std=True,
                  adaptive_std=False,
@@ -153,7 +156,11 @@ class GaussianMLPPolicy(StochasticPolicy):
                                                           self._obs_dim))
             self._dist, mean, log_std = self.model.build(state_input).outputs
             self._f_dist = tf.compat.v1.get_default_session().make_callable(
-                [self._dist.sample(), mean, log_std], feed_list=[state_input])
+                [
+                    self._dist.sample(seed=deterministic.get_tf_seed_stream()),
+                    mean, log_std
+                ],
+                feed_list=[state_input])
 
     @property
     def input_dim(self):
@@ -246,8 +253,7 @@ class GaussianMLPPolicy(StochasticPolicy):
     def clone(self, name):
         """Return a clone of the policy.
 
-        It only copies the configuration of the primitive,
-        not the parameters.
+        It copies the configuration of the primitive and also the parameters.
 
         Args:
             name (str): Name of the newly created policy. It has to be
@@ -258,7 +264,7 @@ class GaussianMLPPolicy(StochasticPolicy):
             garage.tf.policies.GaussianMLPPolicy: Newly cloned policy.
 
         """
-        return self.__class__(
+        new_policy = self.__class__(
             name=name,
             env_spec=self._env_spec,
             hidden_sizes=self._hidden_sizes,
@@ -279,6 +285,8 @@ class GaussianMLPPolicy(StochasticPolicy):
             std_output_nonlinearity=self._std_output_nonlinearity,
             std_parameterization=self._std_parameterization,
             layer_normalization=self._layer_normalization)
+        new_policy.model.parameters = self.model.parameters
+        return new_policy
 
     def __getstate__(self):
         """Object.__getstate__.
