@@ -159,9 +159,3 @@ class TestCategoricalLSTMPolicy(TfGraphTestCase):
         policy = CategoricalLSTMPolicy(env_spec=env.spec,
                                        state_include_action=True)
         assert policy.state_info_specs == [('prev_action', (4, ))]
-
-    def test_clone(self):
-        env = GarageEnv(DummyDiscreteEnv(obs_dim=(10, ), action_dim=4))
-        policy = CategoricalLSTMPolicy(env_spec=env.spec)
-        policy_clone = policy.clone('CategoricalLSTMPolicyClone')
-        assert policy.env_spec == policy_clone.env_spec
